#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-extra
version:              3.1.18
visibility:           public
id:                   wai-extra-3.1.18-65hUHH1RffHL4BiigvOOLm
key:                  wai-extra-3.1.18-65hUHH1RffHL4BiigvOOLm
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  aa938ff194eb38d64717ec91ed20f06c
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-extra-3.1.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-extra-3.1.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-extra-3.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.18-65hUHH1RffHL4BiigvOOLm
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT
    ansi-terminal-1.1-1lvoyaiIx4qBBztkF1DGdA base-4.18.2.1
    base64-bytestring-1.2.1.0-KV8aVMC7eDp4VhaST1z1XE
    bytestring-0.11.5.3 call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    fast-logger-3.2.4-Bl0RjXc09dnKqooEnfDHxC
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    iproute-1.7.15-4god51x9vGqamVzomKHYk
    network-3.1.4.0-6Vir8NKcwTtGDZOkjzNXEQ
    resourcet-1.2.6-52ownTUzBgaCUPB29DeWym
    streaming-commons-0.2.3.1-1dZUgtEvo0vEHNf1cOvTv5 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    vault-0.3.1.6-GpEoifvtFnZC2iN22L9KJY
    wai-3.2.4-JKCq5JcGzi0CtrYAeT794h
    wai-logger-2.5.0-FoEyiLq9IHY402T4GO6Ovh
    warp-3.4.0-46pmJiGox9pGiGB1xG7SW0
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

